==> jc-1.4.0.tar.gz: java/rmi/RMISecurityManager.h <==
// public class java.rmi.RMISecurityManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d38282f3d5f80887 java_lang_SecurityManager
// @dep_class d9f6e331488edff0 java_rmi_RMISecurityManager

// header file dependencies
// @dep_header java_lang_SecurityManager

#include "java/lang/SecurityManager.h"

#ifndef _JC_java_rmi_RMISecurityManager_H_
#define _JC_java_rmi_RMISecurityManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_rmi_RMISecurityManager$sub_refs	_jc_java_rmi_RMISecurityManager$sub_refs;
typedef struct _jc_java_rmi_RMISecurityManager$sub_nonrefs	_jc_java_rmi_RMISecurityManager$sub_nonrefs;
typedef struct _jc_java_rmi_RMISecurityManager$refs	_jc_java_rmi_RMISecurityManager$refs;
typedef struct _jc_java_rmi_RMISecurityManager$nonrefs	_jc_java_rmi_RMISecurityManager$nonrefs;
typedef struct _jc_java_rmi_RMISecurityManager$object	_jc_java_rmi_RMISecurityManager$object;

typedef const struct _jc_java_rmi_RMISecurityManager$vmethods	_jc_java_rmi_RMISecurityManager$vmethods;
typedef const struct _jc_java_rmi_RMISecurityManager$vtable	_jc_java_rmi_RMISecurityManager$vtable;
typedef const struct _jc_java_rmi_RMISecurityManager$vtype	_jc_java_rmi_RMISecurityManager$vtype;

// Constructors
extern void _jc_java_rmi_RMISecurityManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_RMISecurityManager$object *);

// Virtual methods structure
struct _jc_java_rmi_RMISecurityManager$vmethods {
};

// Vtable
struct _jc_java_rmi_RMISecurityManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_SecurityManager$vmethods	java_lang_SecurityManager;
	_jc_java_rmi_RMISecurityManager$vmethods	java_rmi_RMISecurityManager;
};

// Vtype
struct _jc_java_rmi_RMISecurityManager$vtype {
	_jc_type			type;
	_jc_java_rmi_RMISecurityManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_RMISecurityManager$refs {
    _jc_java_rmi_RMISecurityManager$sub_refs	java_rmi_RMISecurityManager;
    _jc_java_lang_SecurityManager$sub_refs	java_lang_SecurityManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RMISecurityManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_SecurityManager$sub_nonrefs	java_lang_SecurityManager;
    _jc_java_rmi_RMISecurityManager$sub_nonrefs	java_rmi_RMISecurityManager;
};

// Object instance structure
struct _jc_java_rmi_RMISecurityManager$object {
	_jc_java_rmi_RMISecurityManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RMISecurityManager$vtype	*vtype;
	_jc_java_rmi_RMISecurityManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RMISecurityManager$vtype _jc_java_rmi_RMISecurityManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RMISecurityManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RMISecurityManager$class_object;

#endif	/* _JC_java_rmi_RMISecurityManager_H_ */

==> jc-1.4.6.tar.gz: java/rmi/RMISecurityManager.h <==
// public class java.rmi.RMISecurityManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d38282f3d5f80887 java_lang_SecurityManager
// @dep_class d9f6e331488edff0 java_rmi_RMISecurityManager

// header file dependencies
// @dep_header java_lang_SecurityManager

#include "java/lang/SecurityManager.h"

#ifndef _JC_java_rmi_RMISecurityManager_H_
#define _JC_java_rmi_RMISecurityManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_rmi_RMISecurityManager$sub_refs	_jc_java_rmi_RMISecurityManager$sub_refs;
typedef struct _jc_java_rmi_RMISecurityManager$sub_nonrefs	_jc_java_rmi_RMISecurityManager$sub_nonrefs;
typedef struct _jc_java_rmi_RMISecurityManager$refs	_jc_java_rmi_RMISecurityManager$refs;
typedef struct _jc_java_rmi_RMISecurityManager$nonrefs	_jc_java_rmi_RMISecurityManager$nonrefs;
typedef struct _jc_java_rmi_RMISecurityManager$object	_jc_java_rmi_RMISecurityManager$object;

typedef const struct _jc_java_rmi_RMISecurityManager$vmethods	_jc_java_rmi_RMISecurityManager$vmethods;
typedef const struct _jc_java_rmi_RMISecurityManager$vtable	_jc_java_rmi_RMISecurityManager$vtable;
typedef const struct _jc_java_rmi_RMISecurityManager$vtype	_jc_java_rmi_RMISecurityManager$vtype;

// Constructors
extern void _jc_java_rmi_RMISecurityManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_RMISecurityManager$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_RMISecurityManager$vmethods {
};

// Vtable
struct _jc_java_rmi_RMISecurityManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_SecurityManager$vmethods	java_lang_SecurityManager;
	_jc_java_rmi_RMISecurityManager$vmethods	java_rmi_RMISecurityManager;
};

// Vtype
struct _jc_java_rmi_RMISecurityManager$vtype {
	_jc_type			type;
	_jc_java_rmi_RMISecurityManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_RMISecurityManager$refs {
    _jc_java_rmi_RMISecurityManager$sub_refs	java_rmi_RMISecurityManager;
    _jc_java_lang_SecurityManager$sub_refs	java_lang_SecurityManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_RMISecurityManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_RMISecurityManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_SecurityManager$sub_nonrefs	java_lang_SecurityManager;
    _jc_java_rmi_RMISecurityManager$sub_nonrefs	java_rmi_RMISecurityManager;
};

// Object instance structure
struct _jc_java_rmi_RMISecurityManager$object {
	_jc_java_rmi_RMISecurityManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_RMISecurityManager$vtype	*vtype;
	_jc_java_rmi_RMISecurityManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_RMISecurityManager$vtype _jc_java_rmi_RMISecurityManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_RMISecurityManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_RMISecurityManager$class_object;

#endif	/* _JC_java_rmi_RMISecurityManager_H_ */
